' ------------------------------------------------------------------------------
' ILctrl 1.0 for Windows
' Copyright (c) 2008-2009  J-F Garnier
'
' This program is free software; you can redistribute it and/or
' modify it under the terms of the GNU General Public License
' as published by the Free Software Foundation; either version 2
' of the License, or (at your option) any later version.
' 
' This program is distributed in the hope that it will be useful,
' but WITHOUT ANY WARRANTY; without even the implied warranty of
' MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
' GNU General Public License for more details.
' 
' You should have received a copy of the GNU General Public License
' along with this program; if not, write to the Free Software
' Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
'
' ----------------------------------------------------------------------------------
'
' ilscope.vb   HPIL scope
'
' ---------------------------------------------------------------------------------

Module ilscope

    ' convert an integer to hex string of 2 characters
    Private Function itoh(ByVal n As Integer) As String
        If (n < 16) Then
            itoh = "0" + Hex(n)
        Else
            itoh = Hex(n)
        End If
    End Function

    ' --------------------------------
    ' ILMnemo()
    ' returns the frame mnemonic
    ' --------------------------------
    Public Function ILMnemo(ByVal frame As Integer) As String
        Dim s As String
        Dim n As Integer

        Dim mnemo As String = "DAB DSR END ESR CMD RDY IDY ISR"
        Dim scmd0 As String = _
         "NUL GTL ??? ??? SDC PPD ??? ??? " & _
         "GET ??? ??? ??? ??? ??? ??? ELN " & _
         "NOP LLO ??? ??? DCL PPU ??? ??? " & _
         "EAR ??? ??? ??? ??? ??? ??? ??? "
        Dim scmd9 As String = _
         "IFC ??? REN NRE ??? ??? ??? ??? " & _
         "??? ??? AAU LPD ??? ??? ??? ??? "

        n = frame And 255
        s = Mid(mnemo, 1 + (frame \ 256) * 4, 3) & " " & itoh(n)

        If ((frame And &H700) = &H400) Then
            ' CMD 
            Select Case (n \ 32)
                Case 0 : s = Mid(scmd0, 1 + (n And 31) * 4, 3)
                Case 1 : If (n And 31) = 31 Then s = "UNL" Else s = "LAD " & itoh(n And 31)
                Case 2 : If (n And 31) = 31 Then s = "UNT" Else s = "TAD " & itoh(n And 31)
                Case 3 : s = "SAD " & itoh(n And 31)
                Case 4
                    If ((n And 31) < 16) Then
                        s = "PPE " & itoh(n And 31)
                    Else
                        s = Mid(scmd9, 1 + (n And 15) * 4, 3)
                    End If
                Case 5 : s = "DDL " & itoh(n And 31)
                Case 6 : s = "DDT " & itoh(n And 31)
            End Select
            If (Left(s, 1) = "?") Then s = "CMD " & itoh(n)

        ElseIf ((frame And &H700) = &H500) Then
            ' RDY 
            If (n < 128) Then
                Select Case (n)
                    Case 0 : s = "RFC"
                    Case 64 : s = "ETO"
                    Case 65 : s = "ETE"
                    Case 66 : s = "NRD"
                    Case 96 : s = "SDA"
                    Case 97 : s = "SST"
                    Case 98 : s = "SDI"
                    Case 99 : s = "SAI"
                    Case 100 : s = "TCT"
                    Case Else : s = "RDY " & itoh(n)
                End Select
            Else
                Select Case (n \ 32)
                    Case 4 : s = "AAD " & itoh(n And 31)
                    Case 5 : s = "AEP " & itoh(n And 31)
                    Case 6 : s = "AES " & itoh(n And 31)
                    Case 7 : s = "AMP " & itoh(n And 31)
                    Case Else : s = "RDY " & itoh(n)
                End Select
            End If
        End If

        While Len(s) < 8
            s = s & " "
        End While

        ILMnemo = s

    End Function




End Module
